#
# spec file for package libmd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
Name:           libmd
VCS: https://src.suse.de/SLFO-pool/libmd#bb9df657fdd1bc9a055e570f77376ba1539a59ed2b57d189e3cd32713ea858b0
Version:        1.1.0
Release:        160000.1.11
Summary:        Message digest functions from BSD systems
License:        BSD-2-Clause OR BSD-3-Clause OR ISC OR SUSE-Public-Domain
URL:            https://www.hadrons.org/software/libmd/
Source0:        https://archive.hadrons.org/software/libmd/libmd-%{version}.tar.xz
Source1:        https://archive.hadrons.org/software/libmd/libmd-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  pkgconfig

%description
The libmd library provides a few message digest ("hash") functions, as
found on various BSDs on a library with the same name and with a compatible
API.

%package -n %{name}%{sover}
Summary:        Provides message digest functions from BSD systems

%description -n %{name}%{sover}
The libmd library provides a few message digest ("hash") functions, as
found on various BSDs on a library with the same name and with a compatible
API.

Digests supported: MD2/4/5, RIPEMD160, SHA1, SHA2-256/384/512.

%package devel
Summary:        Provides message digest functions from BSD systems
Requires:       %{name}%{sover} = %{version}

%description devel
The libmd library provides a few message digest ("hash") functions, as
found on various BSDs on a library with the same name and with a compatible
API.

Digests supported: MD2/4/5, RIPEMD160, SHA1, SHA2-256/384/512.

%prep
%autosetup

%build
%configure \
  --disable-static \
  --disable-silent-rules
  %make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%ldconfig_scriptlets -n %{name}%{sover}

%files -n %{name}%{sover}
%license COPYING
%{_libdir}/%{name}.so.%{sover}*

%files devel
%license COPYING
%doc ChangeLog README
%{_includedir}/*
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/libmd.pc
%{_mandir}/man3/*.3%{?ext_man}
%{_mandir}/man7/libmd.7%{?ext_man}

%changelog
* Tue Jun 20 2023 mpluskal@suse.com
-  Update to version 1.1.0:
  * man: Add new libmd(7) man page
  * doc: Move mailing list reference to the end
  * build: Fix version script linker support detection
  * build: Switch to debian:latest Docker image
  * build: Fix configure.ac indentation
  * build: Require automake 1.11
  * build: Do not use strong aliases on macOS
  * On Darwin use assembler to support symbol aliases
  * build: Rename libmd_alias() to libmd_strong_alias()
  * Remove unused <assert.h>
  * Sync MD2 changes from NetBSD
  * Sync MD4 changes from OpenBSD
  * Sync MD5 changes from OpenBSD
  * Sync RMD160 changes from OpenBSD
  * Sync SHA1 changes from OpenBSD
  * Sync SHA2 changes from OpenBSD
  * test: Add a new test_eq() helper function
  * test: Add cases for SHA224 and SHA512-256
  * build: Terminate lists in variables with «# EOL»
* Sat Oct 16 2021 dmueller@suse.com
- update to 1.0.4:
  * Place static keyword before const in function definitions
  * Declare local functions as static
  * Fix signedness type mismatch comparisons
  * test: Fix pointer type sign mismatch in DEF_TEST_DIGEST() macro
  * man: Document RIPEMD160 and SHA-1 security status
  * build system improvements
* Mon Jan  4 2021 mpluskal@suse.com
- Update to version 1.0.3
  * Import local-link header from libbsd
  * Switch SHA2 symbols from weak to strong aliases
  * build: Move local-link.h from libmd_la_helper_sources to libmd_la_SOURCES
  * build: Only depend on libmd.sym when using it
  * Remove duplicate Files entries from COPYING
  * build: Use <unistd.h> only if available
  * Remove unused weak symbol declarations for MD2 functions
  * build: Ignore release tarballs
  * build: Provide wrapper functions instead of aliases in DLL built with MSVC
  * build: Fix out of tree builds
* Wed Mar  4 2020 schwab@suse.de
- Remove undefined macro
* Tue Aug 13 2019 mpluskal@suse.com
- Enable profile guided optimization
* Fri Dec 14 2018 mpluskal@suse.com
- Update to version 1.0.1:
  * Add missing compatibility macros for SHA384
  * Fix compatibility macros for SHA512
  * test: Refactor and extend message digest testing
  * Add compatibility with Aladdin Enterprises MD5 implementation
  * build: Invoke sed with portable regex
* Fri Feb  2 2018 mpluskal@suse.com
- Update to version 1.0.0:
  * build: Drop GCC specific compiler flag -include
  * build: Detect version script linker support at configure time
  * build: Use an export symbols file if there is no version script
    support
  * build: Do not override the default DEPENDENCIES for libmd
  * Stop using non-portable <sys/param.h>
  * Remove unused __RCSID macro usage
  * Remove unused NEWS file
  * Stop using non-portable <sys/cdefs.h>
  * build: Add -no-undefined libtool flag
  * build: Stop checking for malloc() and memset()
  * build: Switch to AC_C_BIGENDIAN defining WORD_BIGENDIAN
* Thu Jul 21 2016 jengelh@inai.de
- Description update
* Sun Jul 10 2016 mpluskal@suse.com
- Initial package for version 0.0.0
